pub struct MonitorCaptureSourceUpdater<'a> { /* private fields */ }Available on Windows only.
Used to update the source this updater was created from. For more details look at docs for the corresponding builder.
Implementations
Sourceimpl<'a> MonitorCaptureSourceUpdater<'a>
impl<'a> MonitorCaptureSourceUpdater<'a>
pub fn set_monitor_id_raw<T: Into<ObsString> + Sync + Send>( self, monitor_id_raw: T, ) -> Self
Sourcepub fn set_capture_cursor(self, capture_cursor: bool) -> Self
pub fn set_capture_cursor(self, capture_cursor: bool) -> Self
Sets whether the cursor should be captured.
Sourcepub fn set_compatibility(self, compatibility: bool) -> Self
pub fn set_compatibility(self, compatibility: bool) -> Self
Compatibility mode for the monitor capture source.
Sourcepub fn set_force_sdr(self, force_sdr: bool) -> Self
pub fn set_force_sdr(self, force_sdr: bool) -> Self
If the capture should force SDR
Sourceimpl<'a> MonitorCaptureSourceUpdater<'a>
impl<'a> MonitorCaptureSourceUpdater<'a>
Sourcepub fn get_monitors() -> Result<Vec<Sendable<DisplayInfo>>>
pub fn get_monitors() -> Result<Vec<Sendable<DisplayInfo>>>
Gets all available monitors
pub fn set_monitor(self, monitor: &Sendable<DisplayInfo>) -> Self
pub fn set_capture_audio(self, capture_audio: bool) -> Result<Self, String>
Sourceimpl<'a> MonitorCaptureSourceUpdater<'a>
impl<'a> MonitorCaptureSourceUpdater<'a>
pub fn set_capture_method(self, method: ObsDisplayCaptureMethod) -> Self